@@ -108,15 +108,14 @@
 	      ))
        (code "int len = sizeof(\"abc\" \"def\");\n")
        (code "#include <sys/epoll.h>\n")
+       (code "int foo[10];")
        (tree (parse-string code))
        ;;(expr (sx-ref* tree 1 2 1 2 1)) ;; for sizeof("abc"...) demo
 
-       ;;(code "((const char *) \"abc\")")
        ;;(tree (parse-c99x code #:debug #t))
        
        ;;(tree (parse-file "zz.c"))
        ;;(udict (c99-trans-unit->udict/deep tree))
-       ;;(decl1 (sx-ref tree 1))
        ;;(udict (unitize-decl decl1 '()))
        ;;(udecl (udict-struct-ref udict "epoll_event"))
        ;;(udecl (stripdown-udecl udecl))
@@ -124,9 +123,9 @@
        ;;(mdecl (udecl->mspec/comm udecl))
        ;;(udecl (unitize-decl decl))
        ;;(xdecl (expand-typerefs-in-code code 2))
-       (udict (c99-trans-unit->udict/deep tree))
+       ;;(udict (c99-trans-unit->udict/deep tree))
        ;;(udict (c99-trans-unit->udict tree))
-       (udecl (assoc-ref udict '(struct . "epoll_event")))
+       ;;(udecl (assoc-ref udict '(struct . "epoll_event")))
        (rdecl '(decl (decl-spec-list	; raw decl
 		      (@ (attributes "__packed__"))
 		      (type-spec
@@ -143,13 +142,17 @@
 			  (decl-spec-list
 			   (type-spec (typename "epoll_data_t")))
 			  (comp-declr-list (comp-declr (ident "data"))))))))))
-       (udecl (unitize-decl rdecl '()))
+       ;;(udecl (unitize-decl rdecl '()))
+       (udecl (cdar (unitize-decl (sx-ref tree 1) '())))
+       (mdecl (udecl->mdecl udecl))
        )
   ;;(pp tree)
   ;;(pp udict)
-  (pp rdecl)
+  ;;(pp rdecl)
   (pp udecl)
-  (pp99 (cdar udecl))
+  (pp mdecl)
+  (pp (mdecl->udecl mdecl))
+  ;;(pp99 (cdar udecl))
   ;;(pp mdecl)
   ;;(pp xdecl)
   ;;(ppsx udecl)
