@@ -32,6 +32,9 @@
 ;; 1) add renamer
 ;; 2) think about cnvt-fctn that generates C code
 ;; 3) add code for bytestructures' bounding-struct-descriptor
+;; 4) cnvt-udecl needs complete rewrite using udecl->mdecl from c99/munge
+;; 6) generalize: typedef <anything> *foo_t;
+;; 7) generalize: typedef <anything> foo_t[];
 
 ;; Issue:
 ;; So issue is when 'typedef struct ref foo_t' has no 'struct def'
@@ -89,14 +92,12 @@
   #:use-module (ice-9 regex)
   #:use-module (ice-9 pretty-print)
   #:re-export (*nyacc-version*)
-  #:version (0 92 0))
+  #:version (0 94 0))
 
 (define fh-cpp-defs
   (cond
    ((string-contains %host-type "darwin")
-    ;;'("__GNUC__=6" "__signed=signed")
-    (remove (lambda (s)
-	      (string-contains s "_ENVIRONMENT_MAC_OS_X_VERSION"))
+    (remove (lambda (s) (string-contains s "_ENVIRONMENT_MAC_OS_X_VERSION"))
 	    (get-gcc-cpp-defs)))
    (else (get-gcc-cpp-defs))))
     
@@ -591,7 +592,7 @@
   (let* ((field-list (clean-field-list field-list)) ; remove lone comments
 	 (uflds (fold-right unitize-comp-decl '() (cdr field-list))))
     ;;(sferr "field-list:\n") (pperr field-list)
-    (let iter ((decls uflds))
+    (let loop ((decls uflds))
       (if (null? decls) '()
 	  (let* ((name (caar decls))
 		 (udecl (cdar decls))
@@ -602,9 +603,9 @@
 		 (type (mtail->bs-desc tail)))
 	    (cond
 	     ((and (pair? type) (eq? 'bit-field (car type)))
-	      (acons-bfld name type (iter (cdr decls)))) ; bit-field
+	      (acons-bfld name type (loop (cdr decls)))) ; bit-field
 	     (else
-	      (acons-defn name type (iter (cdr decls))))))))))
+	      (acons-defn name type (loop (cdr decls))))))))))
 
 ;; @deffn {Procedure} cnvt-aggr-def aggr-t typename aggr-name field-list
 ;; Output an aggregate definition, where
@@ -786,7 +787,7 @@
      ;; TODO check libffi on how unions are passed and returned.
      ;; I assume here never passed as a floating point.
      ;; This should use bounding-struct-descriptor from bytestructures
-     (let iter ((type #f) (size 0) (flds fields))
+     (let loop ((type #f) (size 0) (flds fields))
        (if (null? flds)
 	   (case type ((double) 'ffi:uint64) ((float) 'ffi:uint32) (else type))
 	   (let* ((udict (unitize-comp-decl (car flds)))
@@ -797,8 +798,8 @@
 		  (ftval (assq-ref ffi-symmap ftype))
 		  (fsize (sizeof ftval)))
 	     (if (> fsize size)
-		 (iter ftype fsize (cdr flds))
-		 (iter type size (cdr flds)))))))
+		 (loop ftype fsize (cdr flds))
+		 (loop type size (cdr flds)))))))
     (((union-def (ident ,name) ,field-list))
      (mtail->ffi-desc `((union-def ,field-list))))
     
@@ -825,7 +826,7 @@
 (define (gen-decl-params params)
   ;; Note that expand-typerefs will not eliminate enums or struct-refs :
   ;; mtail->ffi-desc needs to convert enum to int or void*
-  (let iter ((ix 0) (params (fix-params params)))
+  (let loop ((ix 0) (params (fix-params params)))
     (cond
      ((null? params) '())
      ;;((equal? (car params) '(ellipsis)) (fherr/once "no varargs (yet)") '...)
@@ -837,12 +838,12 @@
 	     (mdecl (udecl->mdecl udecl1 #:add-name (int->name ix))))
 	;;(sferr "  ~S\n" udecl1)
 	(cons (mtail->ffi-desc (cdr mdecl))
-	      (iter (1+ ix) (cdr params))))))))
+	      (loop (1+ ix) (cdr params))))))))
 
 (define (gen-bs-decl-params params)
   ;; Note that expand-typerefs will not eliminate enums or struct-refs :
   ;; mtail->ffi-desc needs to convert enum to int or void*
-  (let iter ((ix 0) (params (fix-params params)))
+  (let loop ((ix 0) (params (fix-params params)))
     (cond
      ((null? params) '())
      ((equal? (car params) '(ellipsis)) '())
@@ -851,7 +852,7 @@
 	     (udecl1 (udecl-rem-type-qual udecl1))
 	     (mdecl (udecl->mdecl udecl1 #:add-name (int->name ix))))
 	(cons (mtail->bs-desc (cdr mdecl))
-	      (iter (1+ ix) (cdr params))))))))
+	      (loop (1+ ix) (cdr params))))))))
 
 ;; === function calls : unwrap args, call, wrap return
 
@@ -1044,9 +1045,9 @@
 		    (init-declr (ident ,(simple-format #f "arg-~A" ix)))))
       (,otherwise param-decl)))
 
-  (let iter ((ix 0) (decls (remove-void-param param-decls)))
+  (let loop ((ix 0) (decls (remove-void-param param-decls)))
     (if (null? decls) '()
-	(cons (fix-param (car decls) ix) (iter (1+ ix) (cdr decls))))))
+	(cons (fix-param (car decls) ix) (loop (1+ ix) (cdr decls))))))
 
 ;; @deffn {Procedure} cnvt-fctn name specl params
 ;; name is string
@@ -1619,7 +1620,7 @@
        (cond
 	((back-ref-getall udecl) =>
 	 (lambda (name-list)
-	   (sferr "  back-ref\n")
+	   ;;(sferr "  back-ref\n")
 	   (cnvt-union-def #f #f union-name field-list)
 	   (for-each
 	    (lambda (typename)
@@ -1764,7 +1765,7 @@
        (let* ((typename "haddr_t")
 	      (size (+ (sizeof '*) 4))
 	      )
-	 (sfscm "(define-public ~A-desc (bs:vector ~A '*))\n" size typename)
+	 (sfscm "(define-public ~A-desc (bs:vector ~A '*))\n" typename size)
 	 ;;(sfscm "(define-fh-compound-type/p ~A ~A-desc)\n" typename typename)
 	 (fhscm-def-compound typename)
 	 (values (cons typename wrapped) (cons typename defined))))
@@ -1777,7 +1778,17 @@
 	       (ptr-declr (pointer) (ident "GtkStock"))))
        (sferr "missed gtk3 decl not expanded\n")
        (values wrapped defined))
-      
+
+      ;; from uuid.h
+      ((udecl (decl-spec-list
+	       (stor-spec (typedef))
+	       (type-spec (fixed-type "unsigned char")))
+	      (init-declr
+	       (array-of (ident ,typename) (p-expr (fixed ,len)))))
+       (sfscm "(define-public ~A-desc (bs:vector ~A uint8))\n" typename len)
+       (fhscm-def-compound typename)
+       (values (cons typename wrapped) (cons typename defined)))
+
       ;; === missed =====================
 
       (,otherwise
@@ -2077,9 +2088,9 @@
       (lambda (wrapped defined)
 	;; Set ffimod-defined for including, but removed built-in types.
 	(let* ((bity (car bs-defined))	; first built-in type
-	       (defd (let iter ((res '()) (defs defined))
+	       (defd (let loop ((res '()) (defs defined))
 		       (if (eq? (car defs) bity) res
-			   (iter (cons (car defs) res) (cdr defs))))))
+			   (loop (cons (car defs) res) (cdr defs))))))
 	  (set! ffimod-defined defd))))
     
     ;; output global constants (from enum and #define)
@@ -2131,9 +2142,9 @@
   (call-with-input-string str
     (lambda (iport)
       (cons 'begin
-	    (let iter ((exp (read iport)))
+	    (let loop ((exp (read iport)))
 	      (if (eof-object? exp) '()
-		  (cons exp (iter (read iport)))))))))
+		  (cons exp (loop (read iport)))))))))
 
 ;; Convert declaration with @var{name} in string-body of C @var{code}
 ;; to string-body of Scheme code.
@@ -2298,18 +2309,18 @@
       (lambda (iport)
 	(let ((env (make-fresh-user-module)))
 	  (eval '(use-modules (nyacc lang c99 ffi-help)) env)
-	  (let iter ((oport #f) (exp (read iport)))
+	  (let loop ((oport #f) (exp (read iport)))
 	    (cond
 	     ((eof-object? exp)
 	      (when oport
 		(display "\n;; --- last line ---\n" oport)
 		(close-port oport)))
 	     ((and (pair? exp) (eqv? 'define-ffi-module (car exp)))
-	      (iter (eval exp env) (read iport)))
+	      (loop (eval exp env) (read iport)))
 	     (else
 	      (when oport
 		(newline oport)
 		(pretty-print exp oport))
-	      (iter oport (read iport))))))))))
+	      (loop oport (read iport))))))))))
 
 ;; --- last line ---
